package com.autentia.adictosaltrabajo.gae.persistence;

import java.util.List;

import javax.jdo.PersistenceManager;
import javax.jdo.Query;

public class TutorialUtils {

	private static final int FETCH_MAX_RESULTS = 10;
	
	/**
	 * Almacenamiento de un nuevo tutorial
	 * @param autor nombre del autor
	 * @param tituloTutorial titulo del tutorial
	 */
	public static void insert(final String autor, final String tituloTutorial) {
		
		// recuperacion del gestor de persistencia de JDO
		final PersistenceManager persistenceManager = PMF.get().getPersistenceManager();
		
		// creamos un nuevo tutorial y los insertamos en el datastore
		final Tutorial tutorial = new Tutorial(autor, tituloTutorial);		
		persistenceManager.makePersistent(tutorial);
	}
	
	/**
	 * Recuperación de los últimos 10 tutoriales (FETCH_MAX_RESULTS)
	 * @return una lista con los últimos 10 tutoriales
	 */
	@SuppressWarnings("unchecked")
	public static List<Tutorial> getEntries() {
		// recuperación del gestor de persistencia de JDO
		final PersistenceManager persistenceManager = PMF.get().getPersistenceManager();

		// generación de la consulta y configuración de la ordenación de los resultados de la misma
		final Query query = persistenceManager.newQuery(Tutorial.class);
	    query.setOrdering("fecha DESC");
	    query.setRange(0, FETCH_MAX_RESULTS);
	    
	    // devolución de resultados
	    return (List<Tutorial>) query.execute();
	}
}
